locat.locat_result module#

class locat.locat_result.LocatResult(gene_name: str, bic: float, zscore: float, sens_score: float, depletion_pval: float, concentration_pval: float, h_size: float, h_sens: float, pval: float, K_components: float, sample_size: float, depletion_scan: dict | None = None)[source]#

Bases: NamedTuple

This class stores the location results for a gene

Methods

count(value, /)

Return number of occurrences of value.

index(value[, start, stop])

Return first index of value.

K_components: float[source]#

The number of components used in the GMM

bic: float[source]#

The BIC score of the analysed gene computed by the GMM

concentration_pval: float[source]#

The depletion p-value of the analysed gene

depletion_pval: float[source]#

The sensitivity score of the analysed gene

depletion_scan: dict | None[source]#

A large amount of debug features

gene_name: str[source]#

The name of the analysed gene

h_sens: float[source]#

The h_sens

h_size: float[source]#

The h_size

pval: float[source]#

The combined p-value

sample_size: float[source]#

The sample size, i.e. the number of cells expressing the gene

sens_score: float[source]#

The sensitivity score of the analysed gene

zscore: float[source]#

The Z-score of the analysed gene